# Importing production modules // Meant for production branch
import os
from dotenv import load_dotenv
from second_brain_tools.time import Today, CURRENT_TIME  # noqa
import second_brain_tools.defaults as sbt_defaults

# Importing production modules finished

# Default Functions Calling
load_dotenv(".sbt_config")
# Default Functions Calling

# Default Append Strings Import Started
DNM_FILE_CONTENT_CREATION = sbt_defaults.DNM_FILE_CONTENT_CREATION
DNBJ_FILE_CONTENT_CREATION = sbt_defaults.DNBJ_FILE_CONTENT_CREATION
DNC_FILE_CONTENT_CREATION = sbt_defaults.DNC_FILE_CONTENT_CREATION
DNE_FILE_CONTENT_CREATION = sbt_defaults.DNE_FILE_CONTENT_CREATION
DNL_FILE_CONTENT_CREATION = sbt_defaults.DNL_FILE_CONTENT_CREATION
DNR_FILE_CONTENT_CREATION = sbt_defaults.DNR_FILE_CONTENT_CREATION
DNR2_FILE_CONTENT_CREATION = sbt_defaults.DNR2_FILE_CONTENT_CREATION
DNT_FILE_CONTENT_CREATION = sbt_defaults.DNT_FILE_CONTENT_CREATION
DNT2_FILE_CONTENT_CREATION = sbt_defaults.DNT2_FILE_CONTENT_CREATION
DNTE_FILE_CONTENT_CREATION = sbt_defaults.DNTE_FILE_CONTENT_CREATION
DNTT_FILE_CONTENT_CREATION = sbt_defaults.DNTT_FILE_CONTENT_CREATION
DNTT2_FILE_CONTENT_CREATION = sbt_defaults.DNTT2_FILE_CONTENT_CREATION
DNTL_FILE_CONTENT_CREATION = sbt_defaults.DNTL_FILE_CONTENT_CREATION
DNTL_FILE_CONTENT_CREATION = sbt_defaults.DNTL_FILE_CONTENT_CREATION
DNTM_FILE_CONTENT_CREATION = sbt_defaults.DNTM_FILE_CONTENT_CREATION
DNTM2_FILE_CONTENT_CREATION = sbt_defaults.DNTM2_FILE_CONTENT_CREATION
DNTM3_FILE_CONTENT_CREATION = sbt_defaults.DNTM3_FILE_CONTENT_CREATION
DNTS_FILE_CONTENT_CREATION = sbt_defaults.DNTS_FILE_CONTENT_CREATION
DNTS2_FILE_CONTENT_CREATION = sbt_defaults.DNTS2_FILE_CONTENT_CREATION
DNTW_FILE_CONTENT_CREATION = sbt_defaults.DNTW_FILE_CONTENT_CREATION
DNR2_HOUR_00_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_00_FILE_CONTENT_CREATION
DNR2_HOUR_01_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_01_FILE_CONTENT_CREATION
DNR2_HOUR_02_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_02_FILE_CONTENT_CREATION
DNR2_HOUR_03_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_03_FILE_CONTENT_CREATION
DNR2_HOUR_04_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_04_FILE_CONTENT_CREATION
DNR2_HOUR_05_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_05_FILE_CONTENT_CREATION
DNR2_HOUR_06_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_06_FILE_CONTENT_CREATION
DNR2_HOUR_07_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_07_FILE_CONTENT_CREATION
DNR2_HOUR_08_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_08_FILE_CONTENT_CREATION
DNR2_HOUR_09_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_09_FILE_CONTENT_CREATION
DNR2_HOUR_10_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_10_FILE_CONTENT_CREATION
DNR2_HOUR_11_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_11_FILE_CONTENT_CREATION
DNR2_HOUR_12_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_12_FILE_CONTENT_CREATION
DNR2_HOUR_13_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_13_FILE_CONTENT_CREATION
DNR2_HOUR_14_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_14_FILE_CONTENT_CREATION
DNR2_HOUR_15_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_15_FILE_CONTENT_CREATION
DNR2_HOUR_16_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_16_FILE_CONTENT_CREATION
DNR2_HOUR_17_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_17_FILE_CONTENT_CREATION
DNR2_HOUR_18_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_18_FILE_CONTENT_CREATION
DNR2_HOUR_19_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_19_FILE_CONTENT_CREATION
DNR2_HOUR_20_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_20_FILE_CONTENT_CREATION
DNR2_HOUR_21_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_21_FILE_CONTENT_CREATION
DNR2_HOUR_22_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_22_FILE_CONTENT_CREATION
DNR2_HOUR_23_FILE_CONTENT_CREATION = sbt_defaults.DNR2_HOUR_23_FILE_CONTENT_CREATION
# Default Append Strings Import Finished

# Default strings from env import Started
SECOND_BRAIN_DIRECTORY = os.getenv("SECOND_BRAIN_DIRECTORY")
FILE_ALREADY_EXIST = os.getenv("FILE_ALREADY_EXIST")
DIR_NOT_FOUND = os.getenv("DIR_NOT_FOUND")
PLAIN_TEXT_TIME_INCLUDE = os.getenv("PLAIN_TEXT_TIME_INCLUDE")
LIST_TIME_INCLUDE = os.getenv("LIST_TIME_INCLUDE")
TIME_APPEND_TEXT = os.getenv("TIME_APPEND_TEXT")
# Default strings from env import Finished

# Append Specific Default strings from env import Started
GLOBAL_APPEND_TYPE = os.getenv("GLOBAL_APPEND_TYPE")
DNM_APPEND_TYPE = os.getenv("DNM_APPEND_TYPE")
DNBJ_APPEND_TYPE = os.getenv("DNBJ_APPEND_TYPE")
DNC_APPEND_TYPE = os.getenv("DNC_APPEND_TYPE")
DNE_APPEND_TYPE = os.getenv("DNE_APPEND_TYPE")
DNL_APPEND_TYPE = os.getenv("DNL_APPEND_TYPE")
DNR_APPEND_TYPE = os.getenv("DNR_APPEND_TYPE")
DNT_APPEND_TYPE = os.getenv("DNT_APPEND_TYPE")
DNT2_APPEND_TYPE = os.getenv("DNT2_APPEND_TYPE")
DNTE_APPEND_TYPE = os.getenv("DNTE_APPEND_TYPE")
DNTT_APPEND_TYPE = os.getenv("DNTT_APPEND_TYPE")
DNTT2_APPEND_TYPE = os.getenv("DNTT2_APPEND_TYPE")
DNTL_APPEND_TYPE = os.getenv("DNTL_APPEND_TYPE")
DNTL_APPEND_TYPE = os.getenv("DNTL_APPEND_TYPE")
DNTM_APPEND_TYPE = os.getenv("DNTM_APPEND_TYPE")
DNTM2_APPEND_TYPE = os.getenv("DNTM2_APPEND_TYPE")
DNTM3_APPEND_TYPE = os.getenv("DNTM3_APPEND_TYPE")
DNTS_APPEND_TYPE = os.getenv("DNTS_APPEND_TYPE")
DNTS2_APPEND_TYPE = os.getenv("DNTS2_APPEND_TYPE")
DNTW_APPEND_TYPE = os.getenv("DNTW_APPEND_TYPE")
DNR2_APPEND_TYPE = os.getenv("DNR2_APPEND_TYPE")

# Hourly Strings < Part of Daily note/Routines
DNR2_HOUR_00_APPEND_TYPE = os.getenv("DNR2_HOUR_00_APPEND_TYPE")
DNR2_HOUR_01_APPEND_TYPE = os.getenv("DNR2_HOUR_01_APPEND_TYPE")
DNR2_HOUR_02_APPEND_TYPE = os.getenv("DNR2_HOUR_02_APPEND_TYPE")
DNR2_HOUR_03_APPEND_TYPE = os.getenv("DNR2_HOUR_03_APPEND_TYPE")
DNR2_HOUR_04_APPEND_TYPE = os.getenv("DNR2_HOUR_04_APPEND_TYPE")
DNR2_HOUR_05_APPEND_TYPE = os.getenv("DNR2_HOUR_05_APPEND_TYPE")
DNR2_HOUR_06_APPEND_TYPE = os.getenv("DNR2_HOUR_06_APPEND_TYPE")
DNR2_HOUR_07_APPEND_TYPE = os.getenv("DNR2_HOUR_07_APPEND_TYPE")
DNR2_HOUR_08_APPEND_TYPE = os.getenv("DNR2_HOUR_08_APPEND_TYPE")
DNR2_HOUR_09_APPEND_TYPE = os.getenv("DNR2_HOUR_09_APPEND_TYPE")
DNR2_HOUR_10_APPEND_TYPE = os.getenv("DNR2_HOUR_10_APPEND_TYPE")
DNR2_HOUR_11_APPEND_TYPE = os.getenv("DNR2_HOUR_11_APPEND_TYPE")
DNR2_HOUR_12_APPEND_TYPE = os.getenv("DNR2_HOUR_12_APPEND_TYPE")
DNR2_HOUR_13_APPEND_TYPE = os.getenv("DNR2_HOUR_13_APPEND_TYPE")
DNR2_HOUR_14_APPEND_TYPE = os.getenv("DNR2_HOUR_14_APPEND_TYPE")
DNR2_HOUR_15_APPEND_TYPE = os.getenv("DNR2_HOUR_15_APPEND_TYPE")
DNR2_HOUR_16_APPEND_TYPE = os.getenv("DNR2_HOUR_16_APPEND_TYPE")
DNR2_HOUR_17_APPEND_TYPE = os.getenv("DNR2_HOUR_17_APPEND_TYPE")
DNR2_HOUR_18_APPEND_TYPE = os.getenv("DNR2_HOUR_18_APPEND_TYPE")
DNR2_HOUR_19_APPEND_TYPE = os.getenv("DNR2_HOUR_19_APPEND_TYPE")
DNR2_HOUR_20_APPEND_TYPE = os.getenv("DNR2_HOUR_20_APPEND_TYPE")
DNR2_HOUR_21_APPEND_TYPE = os.getenv("DNR2_HOUR_21_APPEND_TYPE")
DNR2_HOUR_22_APPEND_TYPE = os.getenv("DNR2_HOUR_22_APPEND_TYPE")
DNR2_HOUR_23_APPEND_TYPE = os.getenv("DNR2_HOUR_23_APPEND_TYPE")

#  Pomodora_1 < Part of Daily note/Routines/Hourly Strings
DNR2_HOUR_00_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_00_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_01_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_01_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_02_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_02_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_03_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_03_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_04_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_04_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_05_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_05_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_06_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_06_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_07_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_07_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_08_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_08_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_09_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_09_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_10_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_10_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_11_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_11_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_12_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_12_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_13_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_13_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_14_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_14_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_15_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_15_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_16_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_16_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_17_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_17_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_18_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_18_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_19_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_19_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_20_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_20_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_21_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_21_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_22_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_22_POMODORA_1_APPEND_TYPE")
DNR2_HOUR_23_POMODORA_1_APPEND_TYPE = os.getenv("DNR2_HOUR_23_POMODORA_1_APPEND_TYPE")


#  Pomodora_2 < Part of Daily note/Routines/Hourly Strings
DNR2_HOUR_00_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_00_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_01_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_01_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_02_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_02_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_03_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_03_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_04_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_04_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_05_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_05_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_06_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_06_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_07_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_07_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_08_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_08_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_09_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_09_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_10_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_10_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_11_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_11_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_12_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_12_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_13_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_13_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_14_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_14_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_15_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_15_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_16_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_16_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_17_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_17_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_18_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_18_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_19_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_19_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_20_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_20_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_21_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_21_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_22_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_22_POMODORA_2_APPEND_TYPE")
DNR2_HOUR_23_POMODORA_2_APPEND_TYPE = os.getenv("DNR2_HOUR_23_POMODORA_2_APPEND_TYPE")
# Append Specific Default strings from env import Finished

# Default examples from env import Started
example = os.getenv("example")
example_elif = os.getenv("example_elif")
# Default examples from env import Started

# Default directories from env import Started
_01 = os.getenv("_01")
_02 = os.getenv("_02")
_03 = os.getenv("_03")
_04 = os.getenv("_04")
_05 = os.getenv("_05")
_06 = os.getenv("_06")
_07 = os.getenv("_07")
_08 = os.getenv("_08")
_01A = os.getenv("_01A")
_01B = os.getenv("_01B")
_01B1 = os.getenv("_01B1")
_01C = os.getenv("_01C")
_01A1 = os.getenv("_01A1")
_01A2 = os.getenv("_01A2")
_01A3 = os.getenv("_01A3")
_01A4 = os.getenv("_01A4")
_01A5 = os.getenv("_01A5")
_01A6 = os.getenv("_01A6")
_01A7 = os.getenv("_01A7")
_01A8 = os.getenv("_01A8")
_01A9 = os.getenv("_01A9")
_01A9A = os.getenv("_01A9A")
_01A9B = os.getenv("_01A9B")
_01A10 = os.getenv("_01A10")
_01A11 = os.getenv("_01A11")
_01A12 = os.getenv("_01A12")
_01A13 = os.getenv("_01A13")
_01A14 = os.getenv("_01A14")
_01A2A = os.getenv("_01A2A")
_01A2B = os.getenv("_01A2B")
_01A2A1 = os.getenv("_01A2A1")
_01A2B1 = os.getenv("_01A2B1")
_01A8A = os.getenv("_01A8A")
_01A8B = os.getenv("_01A8B")
_01A8C = os.getenv("_01A8C")
_01A8D = os.getenv("_01A8D")
_01B = os.getenv("_01B")
_01B2 = os.getenv("_01B2")
_01B3 = os.getenv("_01B3")
_01B3A = os.getenv("_01B3A")
_01B3B = os.getenv("_01B3B")
_01C = os.getenv("_01C")
_01C1 = os.getenv("_01C1")
_01C1A = os.getenv("_01C1A")
_01C1B = os.getenv("_01C1B")
_01C1B1 = os.getenv("_01C1B1")
_01C1C = os.getenv("_01C1C")
_01C1D = os.getenv("_01C1D")
_01C1E = os.getenv("_01C1E")
_01C1E1 = os.getenv("_01C1E1")
_01C1E2 = os.getenv("_01C1E2")
_01C1E3 = os.getenv("_01C1E3")
_01C1E4 = os.getenv("_01C1E4")
_01C1F = os.getenv("_01C1F")
_01C1G = os.getenv("_01C1G")
_01C1G10 = os.getenv("_01C1G10")
_01C1G11 = os.getenv("_01C1G11")
_01C1G12 = os.getenv("_01C1G12")
_01C1G13 = os.getenv("_01C1G13")
_01C1G14 = os.getenv("_01C1G14")
_01C1G15 = os.getenv("_01C1G15")
_01C1G16 = os.getenv("_01C1G16")
_01C1G17 = os.getenv("_01C1G17")
_01C1G18 = os.getenv("_01C1G18")
_01C1G19 = os.getenv("_01C1G19")
_01C1G1 = os.getenv("_01C1G1")
_01C1G20 = os.getenv("_01C1G20")
_01C1G21 = os.getenv("_01C1G21")
_01C1G22 = os.getenv("_01C1G22")
_01C1G23 = os.getenv("_01C1G23")
_01C1G24 = os.getenv("_01C1G24")
_01C1G25 = os.getenv("_01C1G25")
_01C1G2 = os.getenv("_01C1G2")
_01C1G3 = os.getenv("_01C1G3")
_01C1G4 = os.getenv("_01C1G4")
_01C1G5 = os.getenv("_01C1G5")
_01C1G6 = os.getenv("_01C1G6")
_01C1G7 = os.getenv("_01C1G7")
_01C1G8 = os.getenv("_01C1G8")
_01C1G9 = os.getenv("_01C1G9")
_01C1H = os.getenv("_01C1H")
_01C1I = os.getenv("_01C1I")
_01C1I1 = os.getenv("_01C1I1")
_01C1I2 = os.getenv("_01C1I2")
_01C1I3 = os.getenv("_01C1I3")
_01C1I4 = os.getenv("_01C1I4")
_01C1I5 = os.getenv("_01C1I5")
_01C1I6 = os.getenv("_01C1I6")
_01C1I7 = os.getenv("_01C1I7")
_01C1I8 = os.getenv("_01C1I8")
_01C1I9 = os.getenv("_01C1I9")
_01C1I10 = os.getenv("_01C1I10")
_01C1I11 = os.getenv("_01C1I11")
_02A = os.getenv("_02A")
_02B = os.getenv("_02B")
_02A1 = os.getenv("_02A1")
_02A2 = os.getenv("_02A2")
_02A3 = os.getenv("_02A3")
_02B1 = os.getenv("_02B1")
_03A = os.getenv("_03A")
_03B = os.getenv("_03B")
_03C = os.getenv("_03C")
_03D = os.getenv("_03D")
_03A1 = os.getenv("_03A1")
_03A2 = os.getenv("_03A2")
_03A3 = os.getenv("_03A3")
_03A4 = os.getenv("_03A4")
_03B1 = os.getenv("_03B1")
_03B2 = os.getenv("_03B2")
_03B3 = os.getenv("_03B3")
_03B4 = os.getenv("_03B4")
_03B5 = os.getenv("_03B5")
_03B6 = os.getenv("_03B6")
_03B7 = os.getenv("_03B7")
_03B8 = os.getenv("_03B8")
_03B9 = os.getenv("_03B9")
_03B10 = os.getenv("_03B10")
_03B11 = os.getenv("_03B11")
_03C1 = os.getenv("_03C1")
_03C2 = os.getenv("_03C2")
_03C3 = os.getenv("_03C3")
_03C4 = os.getenv("_03C4")
_03C1A = os.getenv("_03C1A")
_03C1B = os.getenv("_03C1B")
_03C1C = os.getenv("_03C1C")
_03C1A1 = os.getenv("_03C1A1")
_03C1A2 = os.getenv("_03C1A2")
_03C1A3 = os.getenv("_03C1A3")
_03C1A4 = os.getenv("_03C1A4")
_03C1A5 = os.getenv("_03C1A5")
_03C1A6 = os.getenv("_03C1A6")
_03C1A7 = os.getenv("_03C1A7")
_03C1A8 = os.getenv("_03C1A8")
_03C1A9 = os.getenv("_03C1A9")
_03C1A10 = os.getenv("_03C1A10")
_03C1A11 = os.getenv("_03C1A11")
_03C1A12 = os.getenv("_03C1A12")
_03C1A13 = os.getenv("_03C1A13")
_03C1A14 = os.getenv("_03C1A14")
_03C1A15 = os.getenv("_03C1A15")
_03C1A16 = os.getenv("_03C1A16")
_03C1A17 = os.getenv("_03C1A17")
_03C1A18 = os.getenv("_03C1A18")
_03C1B1 = os.getenv("_03C1B1")
_03C1C1 = os.getenv("_03C1C1")
_03C2A = os.getenv("_03C2A")
_03C2B = os.getenv("_03C2B")
_03C3A = os.getenv("_03C3A")
_03C3B = os.getenv("_03C3B")
_03C3A1 = os.getenv("_03C3A1")
_03C3A2 = os.getenv("_03C3A2")
_03C3A3 = os.getenv("_03C3A3")
_03C3A4 = os.getenv("_03C3A4")
_03C3B1 = os.getenv("_03C3B1")
_03C4A = os.getenv("_03C4A")
_03D1 = os.getenv("_03D1")
_03D2 = os.getenv("_03D2")
_03D3 = os.getenv("_03D3")
_03D4 = os.getenv("_03D4")
_03D5 = os.getenv("_03D5")
_04A = os.getenv("_04A")
_04B = os.getenv("_04B")
_04C = os.getenv("_04C")
# _04D = os.getenv("_04D")
_04A1 = os.getenv("_04A1")
_04A2 = os.getenv("_04A2")
_04A3 = os.getenv("_04A3")
_04A4 = os.getenv("_04A4")
_04A5 = os.getenv("_04A5")
_04A6 = os.getenv("_04A6")
_04A7 = os.getenv("_04A7")
_04A99 = os.getenv("_04A99")
_04C1 = os.getenv("_04C1")
_05A = os.getenv("_05A")
_05B = os.getenv("_05B")
_05C = os.getenv("_05C")
_05D = os.getenv("_05D")
_05E = os.getenv("_05E")
_06A = os.getenv("_06A")
_06B = os.getenv("_06B")
# _06C = os.getenv("_06C")
# _06D = os.getenv("_06D")
# _06E = os.getenv("_06E")
_06A1 = os.getenv("_06A1")
_06B1 = os.getenv("_06B1")
_06C1 = os.getenv("_06C1")
_06C2 = os.getenv("_06C2")
_06D1 = os.getenv("_06D1")
_06D2 = os.getenv("_06D2")
_06D3 = os.getenv("_06D3")
_07A = os.getenv("_07A")
_07A1 = os.getenv("_07A1")
_07A2 = os.getenv("_07A2")
_07B = os.getenv("_07B")
_07B1 = os.getenv("_07B1")

# Default directories from env import Finished

# User defined directories from env import Finished

"""
Import your directories here
Import your directories here
Import your directories here
Import your directories here
"""

# User defined directories from env import Finished

# Pomodora routines from env started
CR_HOUR_00_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_00_POMODORA_1_TASK_NAME")
CR_HOUR_00_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_00_POMODORA_1_TASK_STATUS")
CR_HOUR_00_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_00_POMODORA_1_TASK_PRIORITY")
CR_HOUR_00_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_00_POMODORA_1_TASK_LABELS")
CR_HOUR_00_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_00_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_00_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_00_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_00_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_00_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_00_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_00_POMODORA_2_TASK_NAME")
CR_HOUR_00_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_00_POMODORA_2_TASK_STATUS")
CR_HOUR_00_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_00_POMODORA_2_TASK_PRIORITY")
CR_HOUR_00_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_00_POMODORA_2_TASK_LABELS")
CR_HOUR_00_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_00_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_00_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_00_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_00_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_00_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_01_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_01_POMODORA_1_TASK_NAME")
CR_HOUR_01_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_01_POMODORA_1_TASK_STATUS")
CR_HOUR_01_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_01_POMODORA_1_TASK_PRIORITY")
CR_HOUR_01_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_01_POMODORA_1_TASK_LABELS")
CR_HOUR_01_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_01_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_01_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_01_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_01_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_01_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_01_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_01_POMODORA_2_TASK_NAME")
CR_HOUR_01_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_01_POMODORA_2_TASK_STATUS")
CR_HOUR_01_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_01_POMODORA_2_TASK_PRIORITY")
CR_HOUR_01_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_01_POMODORA_2_TASK_LABELS")
CR_HOUR_01_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_01_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_01_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_01_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_01_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_01_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_02_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_02_POMODORA_1_TASK_NAME")
CR_HOUR_02_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_02_POMODORA_1_TASK_STATUS")
CR_HOUR_02_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_02_POMODORA_1_TASK_PRIORITY")
CR_HOUR_02_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_02_POMODORA_1_TASK_LABELS")
CR_HOUR_02_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_02_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_02_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_02_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_02_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_02_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_02_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_02_POMODORA_2_TASK_NAME")
CR_HOUR_02_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_02_POMODORA_2_TASK_STATUS")
CR_HOUR_02_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_02_POMODORA_2_TASK_PRIORITY")
CR_HOUR_02_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_02_POMODORA_2_TASK_LABELS")
CR_HOUR_02_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_02_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_02_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_02_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_02_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_02_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_03_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_03_POMODORA_1_TASK_NAME")
CR_HOUR_03_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_03_POMODORA_1_TASK_STATUS")
CR_HOUR_03_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_03_POMODORA_1_TASK_PRIORITY")
CR_HOUR_03_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_03_POMODORA_1_TASK_LABELS")
CR_HOUR_03_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_03_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_03_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_03_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_03_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_03_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_03_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_03_POMODORA_2_TASK_NAME")
CR_HOUR_03_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_03_POMODORA_2_TASK_STATUS")
CR_HOUR_03_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_03_POMODORA_2_TASK_PRIORITY")
CR_HOUR_03_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_03_POMODORA_2_TASK_LABELS")
CR_HOUR_03_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_03_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_03_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_03_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_03_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_03_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_04_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_04_POMODORA_1_TASK_NAME")
CR_HOUR_04_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_04_POMODORA_1_TASK_STATUS")
CR_HOUR_04_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_04_POMODORA_1_TASK_PRIORITY")
CR_HOUR_04_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_04_POMODORA_1_TASK_LABELS")
CR_HOUR_04_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_04_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_04_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_04_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_04_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_04_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_04_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_04_POMODORA_2_TASK_NAME")
CR_HOUR_04_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_04_POMODORA_2_TASK_STATUS")
CR_HOUR_04_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_04_POMODORA_2_TASK_PRIORITY")
CR_HOUR_04_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_04_POMODORA_2_TASK_LABELS")
CR_HOUR_04_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_04_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_04_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_04_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_04_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_04_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_05_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_05_POMODORA_1_TASK_NAME")
CR_HOUR_05_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_05_POMODORA_1_TASK_STATUS")
CR_HOUR_05_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_05_POMODORA_1_TASK_PRIORITY")
CR_HOUR_05_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_05_POMODORA_1_TASK_LABELS")
CR_HOUR_05_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_05_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_05_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_05_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_05_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_05_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_05_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_05_POMODORA_2_TASK_NAME")
CR_HOUR_05_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_05_POMODORA_2_TASK_STATUS")
CR_HOUR_05_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_05_POMODORA_2_TASK_PRIORITY")
CR_HOUR_05_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_05_POMODORA_2_TASK_LABELS")
CR_HOUR_05_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_05_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_05_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_05_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_05_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_05_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_06_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_06_POMODORA_1_TASK_NAME")
CR_HOUR_06_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_06_POMODORA_1_TASK_STATUS")
CR_HOUR_06_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_06_POMODORA_1_TASK_PRIORITY")
CR_HOUR_06_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_06_POMODORA_1_TASK_LABELS")
CR_HOUR_06_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_06_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_06_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_06_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_06_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_06_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_06_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_06_POMODORA_2_TASK_NAME")
CR_HOUR_06_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_06_POMODORA_2_TASK_STATUS")
CR_HOUR_06_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_06_POMODORA_2_TASK_PRIORITY")
CR_HOUR_06_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_06_POMODORA_2_TASK_LABELS")
CR_HOUR_06_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_06_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_06_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_06_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_06_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_06_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_07_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_07_POMODORA_1_TASK_NAME")
CR_HOUR_07_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_07_POMODORA_1_TASK_STATUS")
CR_HOUR_07_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_07_POMODORA_1_TASK_PRIORITY")
CR_HOUR_07_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_07_POMODORA_1_TASK_LABELS")
CR_HOUR_07_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_07_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_07_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_07_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_07_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_07_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_07_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_07_POMODORA_2_TASK_NAME")
CR_HOUR_07_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_07_POMODORA_2_TASK_STATUS")
CR_HOUR_07_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_07_POMODORA_2_TASK_PRIORITY")
CR_HOUR_07_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_07_POMODORA_2_TASK_LABELS")
CR_HOUR_07_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_07_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_07_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_07_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_07_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_07_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_08_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_08_POMODORA_1_TASK_NAME")
CR_HOUR_08_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_08_POMODORA_1_TASK_STATUS")
CR_HOUR_08_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_08_POMODORA_1_TASK_PRIORITY")
CR_HOUR_08_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_08_POMODORA_1_TASK_LABELS")
CR_HOUR_08_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_08_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_08_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_08_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_08_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_08_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_08_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_08_POMODORA_2_TASK_NAME")
CR_HOUR_08_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_08_POMODORA_2_TASK_STATUS")
CR_HOUR_08_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_08_POMODORA_2_TASK_PRIORITY")
CR_HOUR_08_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_08_POMODORA_2_TASK_LABELS")
CR_HOUR_08_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_08_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_08_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_08_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_08_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_08_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_09_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_09_POMODORA_1_TASK_NAME")
CR_HOUR_09_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_09_POMODORA_1_TASK_STATUS")
CR_HOUR_09_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_09_POMODORA_1_TASK_PRIORITY")
CR_HOUR_09_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_09_POMODORA_1_TASK_LABELS")
CR_HOUR_09_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_09_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_09_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_09_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_09_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_09_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_09_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_09_POMODORA_2_TASK_NAME")
CR_HOUR_09_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_09_POMODORA_2_TASK_STATUS")
CR_HOUR_09_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_09_POMODORA_2_TASK_PRIORITY")
CR_HOUR_09_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_09_POMODORA_2_TASK_LABELS")
CR_HOUR_09_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_09_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_09_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_09_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_09_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_09_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_10_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_10_POMODORA_1_TASK_NAME")
CR_HOUR_10_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_10_POMODORA_1_TASK_STATUS")
CR_HOUR_10_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_10_POMODORA_1_TASK_PRIORITY")
CR_HOUR_10_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_10_POMODORA_1_TASK_LABELS")
CR_HOUR_10_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_10_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_10_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_10_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_10_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_10_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_10_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_10_POMODORA_2_TASK_NAME")
CR_HOUR_10_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_10_POMODORA_2_TASK_STATUS")
CR_HOUR_10_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_10_POMODORA_2_TASK_PRIORITY")
CR_HOUR_10_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_10_POMODORA_2_TASK_LABELS")
CR_HOUR_10_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_10_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_10_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_10_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_10_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_10_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_11_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_11_POMODORA_1_TASK_NAME")
CR_HOUR_11_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_11_POMODORA_1_TASK_STATUS")
CR_HOUR_11_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_11_POMODORA_1_TASK_PRIORITY")
CR_HOUR_11_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_11_POMODORA_1_TASK_LABELS")
CR_HOUR_11_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_11_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_11_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_11_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_11_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_11_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_11_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_11_POMODORA_2_TASK_NAME")
CR_HOUR_11_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_11_POMODORA_2_TASK_STATUS")
CR_HOUR_11_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_11_POMODORA_2_TASK_PRIORITY")
CR_HOUR_11_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_11_POMODORA_2_TASK_LABELS")
CR_HOUR_11_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_11_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_11_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_11_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_11_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_11_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_12_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_12_POMODORA_1_TASK_NAME")
CR_HOUR_12_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_12_POMODORA_1_TASK_STATUS")
CR_HOUR_12_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_12_POMODORA_1_TASK_PRIORITY")
CR_HOUR_12_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_12_POMODORA_1_TASK_LABELS")
CR_HOUR_12_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_12_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_12_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_12_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_12_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_12_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_12_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_12_POMODORA_2_TASK_NAME")
CR_HOUR_12_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_12_POMODORA_2_TASK_STATUS")
CR_HOUR_12_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_12_POMODORA_2_TASK_PRIORITY")
CR_HOUR_12_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_12_POMODORA_2_TASK_LABELS")
CR_HOUR_12_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_12_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_12_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_12_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_12_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_12_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_13_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_13_POMODORA_1_TASK_NAME")
CR_HOUR_13_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_13_POMODORA_1_TASK_STATUS")
CR_HOUR_13_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_13_POMODORA_1_TASK_PRIORITY")
CR_HOUR_13_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_13_POMODORA_1_TASK_LABELS")
CR_HOUR_13_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_13_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_13_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_13_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_13_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_13_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_13_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_13_POMODORA_2_TASK_NAME")
CR_HOUR_13_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_13_POMODORA_2_TASK_STATUS")
CR_HOUR_13_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_13_POMODORA_2_TASK_PRIORITY")
CR_HOUR_13_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_13_POMODORA_2_TASK_LABELS")
CR_HOUR_13_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_13_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_13_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_13_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_13_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_13_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_14_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_14_POMODORA_1_TASK_NAME")
CR_HOUR_14_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_14_POMODORA_1_TASK_STATUS")
CR_HOUR_14_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_14_POMODORA_1_TASK_PRIORITY")
CR_HOUR_14_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_14_POMODORA_1_TASK_LABELS")
CR_HOUR_14_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_14_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_14_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_14_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_14_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_14_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_14_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_14_POMODORA_2_TASK_NAME")
CR_HOUR_14_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_14_POMODORA_2_TASK_STATUS")
CR_HOUR_14_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_14_POMODORA_2_TASK_PRIORITY")
CR_HOUR_14_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_14_POMODORA_2_TASK_LABELS")
CR_HOUR_14_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_14_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_14_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_14_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_14_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_14_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_15_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_15_POMODORA_1_TASK_NAME")
CR_HOUR_15_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_15_POMODORA_1_TASK_STATUS")
CR_HOUR_15_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_15_POMODORA_1_TASK_PRIORITY")
CR_HOUR_15_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_15_POMODORA_1_TASK_LABELS")
CR_HOUR_15_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_15_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_15_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_15_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_15_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_15_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_15_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_15_POMODORA_2_TASK_NAME")
CR_HOUR_15_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_15_POMODORA_2_TASK_STATUS")
CR_HOUR_15_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_15_POMODORA_2_TASK_PRIORITY")
CR_HOUR_15_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_15_POMODORA_2_TASK_LABELS")
CR_HOUR_15_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_15_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_15_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_15_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_15_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_15_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_16_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_16_POMODORA_1_TASK_NAME")
CR_HOUR_16_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_16_POMODORA_1_TASK_STATUS")
CR_HOUR_16_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_16_POMODORA_1_TASK_PRIORITY")
CR_HOUR_16_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_16_POMODORA_1_TASK_LABELS")
CR_HOUR_16_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_16_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_16_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_16_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_16_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_16_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_16_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_16_POMODORA_2_TASK_NAME")
CR_HOUR_16_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_16_POMODORA_2_TASK_STATUS")
CR_HOUR_16_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_16_POMODORA_2_TASK_PRIORITY")
CR_HOUR_16_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_16_POMODORA_2_TASK_LABELS")
CR_HOUR_16_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_16_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_16_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_16_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_16_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_16_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_17_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_17_POMODORA_1_TASK_NAME")
CR_HOUR_17_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_17_POMODORA_1_TASK_STATUS")
CR_HOUR_17_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_17_POMODORA_1_TASK_PRIORITY")
CR_HOUR_17_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_17_POMODORA_1_TASK_LABELS")
CR_HOUR_17_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_17_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_17_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_17_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_17_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_17_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_17_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_17_POMODORA_2_TASK_NAME")
CR_HOUR_17_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_17_POMODORA_2_TASK_STATUS")
CR_HOUR_17_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_17_POMODORA_2_TASK_PRIORITY")
CR_HOUR_17_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_17_POMODORA_2_TASK_LABELS")
CR_HOUR_17_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_17_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_17_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_17_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_17_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_17_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_18_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_18_POMODORA_1_TASK_NAME")
CR_HOUR_18_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_18_POMODORA_1_TASK_STATUS")
CR_HOUR_18_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_18_POMODORA_1_TASK_PRIORITY")
CR_HOUR_18_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_18_POMODORA_1_TASK_LABELS")
CR_HOUR_18_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_18_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_18_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_18_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_18_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_18_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_18_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_18_POMODORA_2_TASK_NAME")
CR_HOUR_18_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_18_POMODORA_2_TASK_STATUS")
CR_HOUR_18_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_18_POMODORA_2_TASK_PRIORITY")
CR_HOUR_18_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_18_POMODORA_2_TASK_LABELS")
CR_HOUR_18_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_18_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_18_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_18_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_18_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_18_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_19_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_19_POMODORA_1_TASK_NAME")
CR_HOUR_19_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_19_POMODORA_1_TASK_STATUS")
CR_HOUR_19_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_19_POMODORA_1_TASK_PRIORITY")
CR_HOUR_19_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_19_POMODORA_1_TASK_LABELS")
CR_HOUR_19_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_19_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_19_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_19_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_19_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_19_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_19_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_19_POMODORA_2_TASK_NAME")
CR_HOUR_19_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_19_POMODORA_2_TASK_STATUS")
CR_HOUR_19_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_19_POMODORA_2_TASK_PRIORITY")
CR_HOUR_19_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_19_POMODORA_2_TASK_LABELS")
CR_HOUR_19_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_19_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_19_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_19_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_19_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_19_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_20_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_20_POMODORA_1_TASK_NAME")
CR_HOUR_20_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_20_POMODORA_1_TASK_STATUS")
CR_HOUR_20_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_20_POMODORA_1_TASK_PRIORITY")
CR_HOUR_20_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_20_POMODORA_1_TASK_LABELS")
CR_HOUR_20_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_20_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_20_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_20_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_20_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_20_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_20_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_20_POMODORA_2_TASK_NAME")
CR_HOUR_20_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_20_POMODORA_2_TASK_STATUS")
CR_HOUR_20_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_20_POMODORA_2_TASK_PRIORITY")
CR_HOUR_20_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_20_POMODORA_2_TASK_LABELS")
CR_HOUR_20_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_20_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_20_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_20_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_20_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_20_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_21_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_21_POMODORA_1_TASK_NAME")
CR_HOUR_21_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_21_POMODORA_1_TASK_STATUS")
CR_HOUR_21_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_21_POMODORA_1_TASK_PRIORITY")
CR_HOUR_21_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_21_POMODORA_1_TASK_LABELS")
CR_HOUR_21_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_21_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_21_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_21_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_21_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_21_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_21_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_21_POMODORA_2_TASK_NAME")
CR_HOUR_21_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_21_POMODORA_2_TASK_STATUS")
CR_HOUR_21_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_21_POMODORA_2_TASK_PRIORITY")
CR_HOUR_21_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_21_POMODORA_2_TASK_LABELS")
CR_HOUR_21_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_21_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_21_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_21_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_21_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_21_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_22_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_22_POMODORA_1_TASK_NAME")
CR_HOUR_22_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_22_POMODORA_1_TASK_STATUS")
CR_HOUR_22_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_22_POMODORA_1_TASK_PRIORITY")
CR_HOUR_22_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_22_POMODORA_1_TASK_LABELS")
CR_HOUR_22_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_22_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_22_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_22_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_22_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_22_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_22_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_22_POMODORA_2_TASK_NAME")
CR_HOUR_22_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_22_POMODORA_2_TASK_STATUS")
CR_HOUR_22_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_22_POMODORA_2_TASK_PRIORITY")
CR_HOUR_22_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_22_POMODORA_2_TASK_LABELS")
CR_HOUR_22_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_22_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_22_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_22_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_22_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_22_POMODORA_2_TASK_SUB_TASK")
CR_HOUR_23_POMODORA_1_TASK_NAME = os.getenv("CR_HOUR_23_POMODORA_1_TASK_NAME")
CR_HOUR_23_POMODORA_1_TASK_STATUS = os.getenv("CR_HOUR_23_POMODORA_1_TASK_STATUS")
CR_HOUR_23_POMODORA_1_TASK_PRIORITY = os.getenv("CR_HOUR_23_POMODORA_1_TASK_PRIORITY")
CR_HOUR_23_POMODORA_1_TASK_LABELS = os.getenv("CR_HOUR_23_POMODORA_1_TASK_LABELS")
CR_HOUR_23_POMODORA_1_TASK_DEPENDENCIES = os.getenv("CR_HOUR_23_POMODORA_1_TASK_DEPENDENCIES")
CR_HOUR_23_POMODORA_1_TASK_PARENT_TASK = os.getenv("CR_HOUR_23_POMODORA_1_TASK_PARENT_TASK")
CR_HOUR_23_POMODORA_1_TASK_SUB_TASK = os.getenv("CR_HOUR_23_POMODORA_1_TASK_SUB_TASK")
CR_HOUR_23_POMODORA_2_TASK_NAME = os.getenv("CR_HOUR_23_POMODORA_2_TASK_NAME")
CR_HOUR_23_POMODORA_2_TASK_STATUS = os.getenv("CR_HOUR_23_POMODORA_2_TASK_STATUS")
CR_HOUR_23_POMODORA_2_TASK_PRIORITY = os.getenv("CR_HOUR_23_POMODORA_2_TASK_PRIORITY")
CR_HOUR_23_POMODORA_2_TASK_LABELS = os.getenv("CR_HOUR_23_POMODORA_2_TASK_LABELS")
CR_HOUR_23_POMODORA_2_TASK_DEPENDENCIES = os.getenv("CR_HOUR_23_POMODORA_2_TASK_DEPENDENCIES")
CR_HOUR_23_POMODORA_2_TASK_PARENT_TASK = os.getenv("CR_HOUR_23_POMODORA_2_TASK_PARENT_TASK")
CR_HOUR_23_POMODORA_2_TASK_SUB_TASK = os.getenv("CR_HOUR_23_POMODORA_2_TASK_SUB_TASK")
# Pomodora routines from env finished



# Importing production modules
import typer
import os
from second_brain_tools.setup import setup as sbt_setup
from second_brain_tools.quick_capture import quick_capture
from second_brain_tools.misc import random_file_from_dir
from second_brain_tools.directories import initial_check
from second_brain_tools.daily_note import (
    daily_note_bullet_journal_append,
    daily_note_bullet_journal_pregenerate_check,
    daily_note_moc_append,
    daily_note_moc_pregenerate_check,
)
from second_brain_tools.capture import (
    capture_link,
    capture_thought,
    capture_event,
    capture_task,
    capture_reminder,
    capture_meal,
    capture_sleep,
    capture_medicine,
    capture_mood,
    capture_water_intake,
    capture_exercise,
    capture_transaction,
    capture_symptom,
)
from second_brain_tools.notes import create_note, delete_note, move_note, view_note

# Importing production modules finished

# importing modules that are needed by other modules
from rich.console import List, Capture, Console  # noqa: F401
from rich.markdown import Markdown  # noqa: F401
from rich import print


# Main function, which calls typer app here
def main():
    """
    Main Function, aka CLI app.
    """
    app()
    return 0


# Typer app Started

# Defining typers Started
app = typer.Typer()
app_notes = typer.Typer()
app_daily_note = typer.Typer()
app_capture = typer.Typer()
app_config = typer.Typer()
# Defining typers Finished

# Adding typers to main app Started
app.add_typer(app_notes, name="Notes", help="Notes specific commands.")
app.add_typer(app_capture, name="Capture", help="Capture a note using predefined flows.")
app.add_typer(app_daily_note, name="Daily-Note", help="Daily Note Specific Commands.")
app.add_typer(app_config, name="Config", help="Shows you configurable options.")
# Adding typers to main app Finished

# Typer app Finished


# Starting the app fx()
@app.command("Quick-Capture")
def quick_capture_cli(name: str = typer.Option(..., prompt=True), content: str = typer.Option(..., prompt=True)):
    """
    Quickly capture a note in your inbox.
    """
    quick_capture(name, content)


@app.command("Bullet-Journal")
def daily_note_bullet_journal_cli(content: str = typer.Option(..., prompt=True)):
    """
    Capture a bullet point to your journal.
    """
    daily_note_bullet_journal_pregenerate_check()
    daily_note_bullet_journal_append(content)
    return


@app.command("Random-Note")
def random_note_cli(dir_code: str = typer.Option("04A", prompt=False)):
    """
    View a random note from your vault.
    """
    random_file_from_dir(dir_code)


# Adding app_config commands Started
@app_config.command("Setup")
def config_setup_cli():
    """
    A setup wizard to configure second_brain_tools.
    """
    sbt_setup()


@app_config.command("Check")
def config_check_cli(dir_code):
    """
    A Check Wizard which validates if a directory exist with dir_code provided
    """
    ccc_dir = initial_check(dir_code)
    ccc_check = os.path.isdir(ccc_dir)
    if ccc_check is True:
        print("The directory exists")
    else:
        print("The directory does not exist")


# Adding app_config commands Finished


# Adding app_capture commands Started
@app_capture.command("Thought")
def capture_thought_cli(
    name: str = typer.Option(..., prompt=True),
    summary: str = typer.Option(..., prompt=True),
    content: str = typer.Option(..., prompt=True),
):
    """
    Got a thought, capture it!
    """
    capture_thought(name, summary, content)


@app_capture.command("Link")
def capture_link_cli(
    url: str = typer.Option(..., prompt=True),
):
    """
    Got a url/link? Capture it.
    """
    capture_link(url)


@app_capture.command("Event")
def capture_event_cli(
    name: str = typer.Option(..., prompt=True),
    Type: str = typer.Option(..., prompt=True),
    location: str = typer.Option(..., prompt=True),
    summary: str = typer.Option(..., prompt=True),
    status: str = typer.Option(..., prompt=True),
):
    """
    Capture an event
    """
    capture_event(name, Type, location, summary, status)


@app_capture.command("Task")
def capture_task_cli(
    name: str = typer.Option(..., prompt=True),
    status: str = typer.Option(..., prompt=True),
    priority: str = typer.Option(..., prompt=True),
    labels: str = typer.Option(..., prompt=True),
    dependencies: str = typer.Option("NULL", prompt=True),
    parent_task: str = typer.Option("NULL", prompt=True),
    sub_task: str = typer.Option("NULL", prompt=True),
):
    """
    Capture a todo task
    """
    capture_task(name, status, priority, labels, dependencies, parent_task, sub_task)


@app_capture.command("Reminder")
def capture_reminder_cli(
    name: str = typer.Option(..., prompt=True),
    priority: str = typer.Option(..., prompt=True),
    labels: str = typer.Option(..., prompt=True),
    time_to_remind: str = typer.Option(..., prompt=True),
):
    """
    Capture a reminder.
    """
    capture_reminder(name, priority, labels, time_to_remind)


@app_capture.command("Meal")
def capture_meal_cli(
    name: str = typer.Option(..., prompt=True),
    time: str = typer.Option(..., prompt=True),
    Type: str = typer.Option(..., prompt=True),
    calories: str = typer.Option(..., prompt=True),
    taken: str = typer.Option(..., prompt=True)
):
    """
    Capture a meal.
    """
    capture_meal(name, time, Type, calories, taken)


@app_capture.command("Sleep")
def capture_sleep_cli(
    Name: str = typer.Option(..., prompt=True),
    Type: str = typer.Option(..., prompt=True),
    Hours: str = typer.Option(..., prompt=True),
    Time: str = typer.Option(..., prompt=True),
):
    """
    Capture a nap.
    """
    capture_sleep(Name, Type, Hours, Time)


@app_capture.command("Medicine")
def capture_medicine_cli(
    name: str = typer.Option(..., prompt=True),
    time: str = typer.Option(..., prompt=True),
    Type: str = typer.Option(..., prompt=True),
    taken: str = typer.Option(..., prompt=True),
):
    """
    Capture your medicine.
    """
    capture_medicine(name, time, Type, taken)


@app_capture.command("Mood")
def capture_mood_cli(
    name: str = typer.Option(..., prompt=True),
    status: str = typer.Option(..., prompt=True),
    reason: str = typer.Option(..., prompt=True),
):
    """
    Capture your mood.
    """
    capture_mood(name, status, reason)


@app_capture.command("Water-Intake")
def capture_water_intake_cli(
    name: str = typer.Option(..., prompt=True),
    time: str = typer.Option(..., prompt=True),
    amount: str = typer.Option(..., prompt=True),
):
    """
    Capture your water intake.
    """
    capture_water_intake(name, time, amount)


@app_capture.command("Exercise")
def capture_exercise_cli(
    name: str = typer.Option(..., prompt=True),
    time: str = typer.Option(..., prompt=True),
    cohort: str = typer.Option(..., prompt=True),
    status: str = typer.Option(..., prompt=True),
):
    """
    Capture your exercise/workouts.
    """
    capture_exercise(name, time, cohort, status)


@app_capture.command("Transaction")
def capture_transaction_cli(
    name: str = typer.Option(..., prompt=True),
    time: str = typer.Option(..., prompt=True),
    type: str = typer.Option(..., prompt=True),
    amount: str = typer.Option(..., prompt=True),
    account: str = typer.Option(..., prompt=True),
    invoice_url: str = typer.Option(..., prompt=True),
):
    """
    Capture a transaction.
    """
    capture_transaction(name, time, type, amount, account, invoice_url)


@app_capture.command("Symptom")
def capture_symptom_cli(
    name: str = typer.Option(..., prompt=True),
    status: str = typer.Option(..., prompt=True),
):
    """
    Capture a symptom.
    """
    capture_symptom(name, status)


# Adding app_capture commands Finished


# Adding app_notes commands Started
@app_notes.command("Create")
def notes_create_cli(
    dir_code: str = typer.Option(..., prompt=True),
    note_name: str = typer.Option(..., prompt=True),
    note_body: str = typer.Option(..., prompt=True),
):
    """
    Create a note in your desired directory.
    """
    create_note(dir_code, note_name, note_body)
    return


@app_notes.command("View")
def notes_view_cli(
    dir_code: str = typer.Option(..., prompt=True),
    note_name: str = typer.Option(..., prompt=True),
):
    """
    View a note in your desired directory.
    """
    view_note(dir_code, note_name)
    return


@app_notes.command("Move")
def notes_move_cli(
    old_dir_code: str = typer.Option(..., prompt=True),
    new_dir_code: str = typer.Option(..., prompt=True),
    note_name: str = typer.Option(..., prompt=True),
):
    """
    Move a note from/to your desired directory.
    """
    move_note(old_dir_code, new_dir_code, note_name)
    return


@app_notes.command("Delete")
def notes_delete_cli(
    dir_code: str = typer.Option(..., prompt=True),
    note_name: str = typer.Option(..., prompt=True),
):
    """
    Deleted a note from your desired directory.
    """
    delete_note(dir_code, note_name)
    return


# Adding app_notes commands Finished


# Adding app_daily_note commands Started


@app_daily_note.command("Append")
def daily_note_append_cli(
    content: str = typer.Option(..., prompt=True),
):
    "Append your daily note MOC using sbt."
    daily_note_moc_pregenerate_check()
    daily_note_moc_append(content)
    return

# daily_note_bullet_journal_append
# Adding app_daily_note commands Finished
# Adding app commands Finished



import re


def get_domain(url):
    # Use a regular expression to extract the domain from the URL
    domain_regex = re.compile(r"(?:https?://)?(?:www\.)?([^/]+)")
    match = domain_regex.search(url)
    if match:
        return match.group(1)
    else:
        return None


def get_last_section_of_url(url):
    # Split the URL by '/' character
    url_sections = url.split('/')
    # Get the last element of the resulting list
    last_section = url_sections[-1]
    if not last_section:
        last_section = url_sections[-2]
    return last_section



# importing modules started
import os
from second_brain_tools.directories import initial_check
from second_brain_tools.config import SECOND_BRAIN_DIRECTORY
from rich.console import Console
from rich.markdown import Markdown
from rich import print

# importing modules finished


def create_note(dir_code, note_name, note_body):
    note_path = SECOND_BRAIN_DIRECTORY + initial_check(dir_code) + note_name + ".md"
    with open(note_path, 'w') as cn_obj_1:
        cn_obj_1.write(note_body)


def delete_note(dir_code, note_name):
    note_path = SECOND_BRAIN_DIRECTORY + initial_check(dir_code) + note_name + ".md"
    print(f"Caution, You are deleting a file at \n {note_path}")
    choice = input("Are you sure, you want to delte this file?(Y/N): ")
    if choice == "Y":
        os.remove(note_path)
    elif choice == "N":
        print("Aborting!!!")


def move_note(old_dir_code, new_dir_code, note_name):
    odc_note_path = SECOND_BRAIN_DIRECTORY + initial_check(old_dir_code) + note_name + ".md"
    ndc_note_path = SECOND_BRAIN_DIRECTORY + initial_check(new_dir_code) + note_name + ".md"
    os.replace(odc_note_path, ndc_note_path)


def view_note(dir_code, note_name):
    note_path = SECOND_BRAIN_DIRECTORY + initial_check(dir_code) + note_name + ".md"
    with open(note_path, 'r') as vn:
        content = vn.read()
        console = Console()
        console.print(Markdown(content))



"""
This module contains all the functions which are miscellaneous by nature.
Which means they are either very micro and/or too micro to hold somewhere else.
"""
import os
import random
from second_brain_tools.defaults import NO_MARKDOWN_FILE
from rich.console import Console
from second_brain_tools.config import SECOND_BRAIN_DIRECTORY
from rich.markdown import Markdown
from rich import print
from second_brain_tools.directories import initial_check


def file_name_check(fnc_name):
    """
    Takes file name and checks if it is empty or not and mark it as valid/invalid.
    returns false if invalid, else True if valid.
    """
    fnc_check = len(fnc_name)
    if fnc_check == "0":
        result = False
    else:
        result = True
    return result


def file_creation(file_location, file_content):
    with open(file_location, 'a+') as qc_object:
        qc_object.write(file_content)


def random_file_from_dir(rffd_dir_code):
    rffd_dir = initial_check(rffd_dir_code)
    random_file = choose_random_markdown_file(rffd_dir)
    view_note_with_dir(random_file)
    return


def choose_random_markdown_file(dir_path):
    # Get a list of all markdown files in the directory
    working_dir = SECOND_BRAIN_DIRECTORY + dir_path
    markdown_files = [f for f in os.listdir(working_dir) if f.endswith('.md')]

    # Choose a random file from the list
    try:
        chosen_file = random.choice(markdown_files)
    except IndexError:
        chosen_file = "The index is out of range!"
    # Return the full path to the chosen file
    return os.path.join(working_dir, chosen_file)


def view_note_with_dir(vnwd_dir):
    if vnwd_dir == '/home/rohan/Vaults/SBT_TOOLS_TESTING/04_Evergreen/04A_Network/The index is out of range!':
        print(NO_MARKDOWN_FILE)
    elif vnwd_dir:
        with open(vnwd_dir, "r") as vnwd_obj:
            content = vnwd_obj.read()
            console = Console()
            console.print(Markdown(content))
    else:
        print(NO_MARKDOWN_FILE)


"""
def get_dir_existence_percentage(dirs):
    # Count the number of directories that exist
    num_dirs_exist = 0
    for dir in dirs:
        if os.path.isdir(dir):
            num_dirs_exist += 1

    # Calculate the percentage of directories that exist
    percentage = (num_dirs_exist / len(dirs)) * 100

    return percentage
"""



"""
This module contain all the functions that are append related.
These functions have a single role that is to append with the given parameters.
"""
# Importing production modules // Meant for production branch
from second_brain_tools.config import PLAIN_TEXT_TIME_INCLUDE, TIME_APPEND_TEXT, CURRENT_TIME, LIST_TIME_INCLUDE
from second_brain_tools.directories import initial_check
from rich import print

# Importing production modules finished

# Default strings assignation Started

# Plain text specific
pta_include_time = PLAIN_TEXT_TIME_INCLUDE
# List Specific
list_append_time = LIST_TIME_INCLUDE

# Default strings assignation Finished


def paragraph_append(note_path, note_content):
    """
    paragraph_append: Appends a new paragraph to a file.

    This function appends a new paragraph to the end of a file.

    Args:
    note_path (str): The path to the file.
    note_content (str): The content of the new paragraph to be appended.

    Returns:
    None
    """
    with open(note_path, 'a+') as pa_object:
        pa_object.write(f" {note_content}")


def plain_text_append(note_path, note_content, pta_include_time):
    """
    plain_text_append: Appends plain text to a file.

    This function appends plain text to the end of a file. The user can choose to include the current time in the text.

    Args:
    note_path (str): The path to the file.
    note_content (str): The plain text to be appended.
    pta_include_time (bool): Whether to include the current time in the text.

    Returns:
    None"""
    if pta_include_time is True:
        opener = TIME_APPEND_TEXT + " " + CURRENT_TIME
        with open(note_path, 'a+') as pta_object:
            pta_object.write("\n")
            # pta_object.write("---\n")
            pta_object.write(opener)
            pta_object.write("\n")
            pta_object.write(note_content + "\n\n")
            pta_object.write("---\n")
            pta_object.write("\n")
    else:
        with open(note_path, 'a+') as pta_object:
            pta_object.write("\n")
            # pta_object.write("---\n")
            pta_object.write("\n")
            pta_object.write(note_content + "\n\n")
            pta_object.write("---\n")
            pta_object.write("\n")


def bullet_list_append(note_path, note_content, list_include_time):
    """
    bullet_list_append: Appends a bullet point to a list in a file.

    This function appends a bullet point to a list in a file. The user can choose to include the current time in the bullet point.

    Args:
    note_path (str): The path to the file.
    note_content (str): The content of the bullet point to be appended.
    list_include_time (bool): Whether to include the current time in the bullet point.

    Returns:
    None"""
    if list_include_time is True:
        with open(note_path, 'a+') as bla_object:
            bla_object.write(f" * {note_content} (at {CURRENT_TIME}) \n")
    else:
        with open(note_path, 'a+') as bla_object:
            bla_object.writelines(f" * {note_content} \n")


def table_append(note_path, note_content):
    """
    table_append: Appends a new row to a table in a file.

    This function appends a new row to a table in a file.
    The new row consists of a single column containing the given content and a second column containing the current time.

    Args:
    note_path (str): The path to the file.
    note_content (str): The content to be added to the first column of the new row.

    Returns:
    None"""
    with open(note_path, 'a+') as ta_object:
        last_line_check = table_append_last_line_check(note_path, note_content)
        if last_line_check is False:
            ta_object.write("| You Logged -> | on |\n")
            ta_object.write("| ------------- | ----- |\n")
            ta_object.write(f"|{note_content}| {CURRENT_TIME} | \n")
        else:
            ta_object.write(f"|{note_content}| {CURRENT_TIME} | \n")


def table_append_last_line_check(note_path, note_content):
    """
        table_append_last_line_check: Checks the last line of a file for a specific string.

    This function checks the last non-empty line of a file for a specific string.

    Args:
    note_path (str): The path to the file.
    note_content (str): The string to search for.

    Returns:
    bool: True if the string is found, False otherwise.
    """
    with open(note_path, 'r') as tallc_object:
        # Read the contents of the file
        contents = tallc_object.read()
        # Split the contents into a list of lines
        lines = contents.split('\n')
        # Iterate over the lines in reverse order
        for line in reversed(lines):
            # Skip empty lines
            if line == '':
                continue
            # Return True if the line matches the given string
            if line == "| ------------- | ----- |":
                return True
        # Return False if no non-empty line is found
        return False


# Append to a note
def append_note(append_type, note_dir_code, note_name, note_content, include_time):
    """
    append_note: Appends content to a file in a specified format.

    This function appends content to a file in a specified format.
    The available formats are "paragraph", "list", "plain_text", and "table".
    The user can choose to include the current time in the content.

    Args:
    append_type (str): The format for the content.
    note_dir_code (str): The code for the directory containing the file.
    note_name (str): The name of the file.
    note_content (str): The content to be appended.
    include_time (bool): Whether to include the current time in the content.

    Returns:
    None
    """
    note_path = initial_check(note_dir_code) + note_name
    if append_type == "paragraph" or "Paragraph" or "PARAGRAPH":
        paragraph_append(note_path, note_content)
    elif append_type == "list" or "LIST" or "List":
        bullet_list_append(note_path, note_content, include_time)
    elif append_type == "plain_text" or "PLAIN_TEXT" or "Plain_Text":
        plain_text_append(note_path, note_content, include_time)
    elif append_type == "table" or "Table" or "TABLE":
        table_append(note_path, note_content)
    else:
        print("Error")
